diff jvmci/jdk.vm.ci.code/src/jdk/vm/ci/code/CallingConvention.java @ 22783:d63506bb5237

Make CallingConvention.Type extensible; remove unused stackOnly parameter
author Christian Wimmer <christian.wimmer@oracle.com>
date Thu, 21 Jan 2016 13:53:26 -0800
parents 1bbd4a7c274b
children 9e1235406b59
line wrap: on
line diff
--- a/jvmci/jdk.vm.ci.code/src/jdk/vm/ci/code/CallingConvention.java	Wed Jan 20 13:56:34 2016 -0800
+++ b/jvmci/jdk.vm.ci.code/src/jdk/vm/ci/code/CallingConvention.java	Thu Jan 21 13:53:26 2016 -0800
@@ -34,35 +34,9 @@
 public class CallingConvention {
 
     /**
      * Constants denoting the type of a call for which a calling convention is requested.
      */
-    public enum Type {
-        /**
-         * A request for the outgoing argument locations at a call site to Java code.
-         */
-        JavaCall(true),
-
-        /**
-         * A request for the incoming argument locations.
-         */
-        JavaCallee(false),
-
-        /**
-         * A request for the outgoing argument locations at a call site to external native code that
-         * complies with the platform ABI.
-         */
-        NativeCall(true);
-
-        /**
-         * Determines if this is a request for the outgoing argument locations at a call site.
-         */
-        public final boolean out;
-
-        public static final Type[] VALUES = values();
-
-        private Type(boolean out) {
-            this.out = out;
-        }
+    public interface Type {
     }
 
     /**
@@ -34,35 +34,9 @@
 
     /**
-     * Constants denoting the type of a call for which a calling convention is requested.
+     * Marker interface denoting the type of a call for which a calling convention is requested.
      */